CloseClickEvent constructor
CloseClickEvent(
- int viewId
Build a CameraMoveStarted Event triggered from the map represented by mapId.
The value of this event is a PanoramaClickData object with the position was long clicked by user.
Implementation
CloseClickEvent(int viewId) : super(viewId, null);