StreetViewPanoramaOptions class
Constructors
-
StreetViewPanoramaOptions({String? panoId, LatLng? position, double? radius, StreetViewSource? source, bool? panningGesturesEnabled, bool? streetNamesEnabled, bool? zoomGesturesEnabled, StreetViewPanoramaCamera? panoramaCamera, Set<
Marker> ? markers, bool? addressControl, ControlPosition? addressControlOptions, bool? disableDefaultUI, bool? disableDoubleClickZoom, bool? enableCloseButton, bool? fullscreenControl, ControlPosition? fullscreenControlOptions, bool? linksControl, bool? motionTracking, bool? motionTrackingControl, ControlPosition? motionTrackingControlOptions, bool? scrollwheel, bool? panControl, ControlPosition? panControlOptions, bool? zoomControl, ControlPosition? zoomControlOptions, bool? visible}) -
StreetViewPanoramaOptions.fromMap(Map<
String, dynamic> map) -
Create StreetViewPanoramaOptions and put data by
map.factory
Properties
- addressControl → bool?
-
The enabled/disabled state of the address control.
Web onlyfinal - addressControlOptions → ControlPosition?
-
The display position for the address control.
Web onlyfinal - disableDefaultUI → bool?
-
Enables/disables all default UI.
Web onlyfinal - disableDoubleClickZoom → bool?
-
Enables/disables zoom on double click. Disabled by default.
Web onlyfinal - enableCloseButton → bool?
-
If true, the close button is displayed. Disabled by default.
Web onlyfinal - fullscreenControl → bool?
-
The enabled/disabled state of the fullscreen control.
Web onlyfinal - fullscreenControlOptions → ControlPosition?
-
The display position for the fullscreen control.
Web onlyfinal - hashCode → int
-
The hash code for this object.
no setteroverride
- linksControl → bool?
-
The enabled/disabled state of the links control.
Web onlyfinal -
markers
→ Set<
Marker> ? -
Markers to be placed on the map.
iOS onlyfinal - motionTracking → bool?
-
Whether motion tracking is on or off.
Web onlyEnabled by default when the motion tracking control is present,so that the POV (point of view) follows the orientation of the device. This is primarily applicable to mobile devices. If motionTracking is set to false while motionTrackingControl is enabled, the motion tracking control appears but tracking is off. The user can tap the motion tracking control to toggle this option.final - motionTrackingControl → bool?
-
The enabled/disabled state of the motion tracking control.
Web onlyEnabled by default when the device has motion data, so that the control appears on the map. This is primarily applicable to mobile devices.final - motionTrackingControlOptions → ControlPosition?
-
The display position for the motion tracking control.
Web onlyfinal - panControl → bool?
-
The enabled/disabled state of the pan control.
Web onlyfinal - panControlOptions → ControlPosition?
-
The display position for the pan control.
Web onlyfinal - panningGesturesEnabled → bool?
-
Sets whether the user is able to use panning gestures
final
- panoId → String?
-
Set initialization location by panorama ID.
position should be null if panoId is given.
final
- panoramaCamera → StreetViewPanoramaCamera?
-
Sets initialization position of camera.
final
- position → LatLng?
-
Set initialization location by latitude and longitude.
panoId should be null if position is given.
final
- radius → double?
-
Set radius to filter initialization panorama.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollwheel → bool?
-
If false, disables scrollwheel zooming in Street View. The scrollwheel is enabled by default.
Web onlyfinal - source → StreetViewSource?
-
Set panorama source filter to search initialization panorama.
final
- streetNamesEnabled → bool?
-
Sets whether the user is able to see street names on panoramas
final
-
Sets whether the user is able to move to another panorama
final
- visible → bool?
-
If true, the Street View panorama is visible on load.
Web onlyfinal - zoomControl → bool?
-
The enabled/disabled state of the zoom control.
Web onlyfinal - zoomControlOptions → ControlPosition?
-
The display position for the zoom control.
Web onlyfinal - zoomGesturesEnabled → bool?
-
Sets whether the user is able to use zoom gestures
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Put all param to a map
-
toString(
) → String -
A string representation of this object.
override
-
updatesMap(
StreetViewPanoramaOptions newOptions) → Map< String, dynamic>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override